pub struct ParseVisibilityError(pub String);Expand description
The error returned when a visibility string is not a known tier.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for ParseVisibilityError
impl Clone for ParseVisibilityError
Sourcefn clone(&self) -> ParseVisibilityError
fn clone(&self) -> ParseVisibilityError
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ParseVisibilityError
impl Debug for ParseVisibilityError
Sourceimpl Display for ParseVisibilityError
impl Display for ParseVisibilityError
impl Eq for ParseVisibilityError
Sourceimpl Error for ParseVisibilityError
impl Error for ParseVisibilityError
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for ParseVisibilityError
impl PartialEq for ParseVisibilityError
Sourcefn eq(&self, other: &ParseVisibilityError) -> bool
fn eq(&self, other: &ParseVisibilityError) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ParseVisibilityError