pub async fn run(setup: BridgeSetup) -> VoidExpand description
Runs the bridge: the MCP stdio peer, one reconnecting WS link per server, and the dispatcher.
Errors
Returns an error if no known server is configured to connect to.
pub async fn run(setup: BridgeSetup) -> VoidRuns the bridge: the MCP stdio peer, one reconnecting WS link per server, and the dispatcher.
Returns an error if no known server is configured to connect to.