load_identity

Function load_identity 

pub fn load_identity(dir: &Path) -> Res<Identity>
Loads the identity whose seed is stored at dir/key.

Errors

Returns an error if the keyfile is missing or does not contain a valid 32-byte seed.