decode

Function decode 

pub fn decode(bytes: &[u8]) -> Res<ProtocolMessage>
Decodes a frame from its wire bytes with the fixed codec configuration.

Errors

Returns an error if the bytes are not a valid encoded frame.