encode

Function encode 

pub fn encode(message: &ProtocolMessage) -> Res<Vec<u8>>
Encodes a frame to its wire bytes with the fixed codec configuration.

Errors

Returns an error if the frame cannot be serialized.