one_shot

Function one_shot 

pub async fn one_shot(
    url: &str,
    identity: &Identity,
    session: &str,
    request: ProtocolMessage,
) -> Res<ProtocolMessage>
Authenticates with the local key on url and performs one request/response control exchange.

Errors

Returns an error if the connection or authentication fails; a server-side rejection of the request itself is returned as a ProtocolMessage::Error value (not an Err).