register

Function register 

pub async fn register(
    url: &str,
    identity: &Identity,
    username: &str,
    machine: &str,
    session: &str,
) -> Res<SessionPath>
Claims a username + enrolls this machine on url, returning the resolved session path.

Errors

Returns an error if the connection, handshake, or registration is rejected.